pywurfl.ql.TypeStr

Package pywurfl :: Module ql :: Class TypeStr |
[hide private]
[frames] | no frames]

# Class TypeStr

source code

    _Type --+
            |
           TypeStr

Instance Methods | [hide private]
substr(self, begin, end) | source code
_match(self, regex, num=0, flags=0) | source code
match(self, regex, num=0) | source code
imatch(self, regex, num=0) | source code
Inherited from `_Type`: `__getattr__`, `__init__`